package de.fhdw.gaming.ipspiel23.ht.domain;

import java.util.Map;
import java.util.Optional;

import de.fhdw.gaming.core.domain.Player;

/**
 * Represents a player of the Heads or Tails game.
 */
public interface IHTPlayer extends Player<IHTPlayer> {

    /**
     * Returns the possible outcomes of this player. The key for the first-level map is the answer of the first player,
     * the key for the second-level map is the answer of the second player.
     */
    Map<Answer, Map<Answer, Double>> getPossibleOutcomes();

    /**
     * Returns the answer of this player.
     */
    Optional<Answer> getAnswer();

    /**
     * Sets the answer of this player.
     *
     * @param newAnswer The answer to set.
     * @throws IllegalStateException if an answer has already been set.
     */
    void setAnswer(Answer newAnswer);

    @Override
    IHTPlayer deepCopy();
}
